.. requests_toolbelt documentation master file, created by
   sphinx-quickstart on Sun Jan 12 21:24:39 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

requests toolbelt
=================

This is a collection of utilities that some users of python-requests might need
but do not belong in requests proper. The library is actively maintained by
members of the requests core development team, and so reflects the
functionality most requested by users of the requests library.

To get an overview of what the library contains, consult the :ref:`user <user>`
documentation.

Overview
--------

.. toctree::
    :maxdepth: 1

    user
    contributing

Full Documentation
------------------

.. toctree::
    :maxdepth: 2

    adapters
    authentication
    deprecated
    downloadutils
    dumputils
    formdata
    exceptions
    sessions
    threading
    uploading-data
    user-agent

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
